@@ -41,7 +41,7 @@ TRY:
    }
    close $wtr or die "$desc: close() failed : $!";
    eval {
-    local $SIG{ALRM} = sub { die 'alarm' };
+    local $SIG{ALRM} = sub { die 'timeout' };
     my $a = (int(100 * (3 * $l) / $speed) || 1);
     $a = 10 if $a > 10;
     alarm $a;
